@@ -206,7 +206,24 @@ def _send_trace_to_api(
             method="POST",
         )
 
-        with urllib.request.urlopen(request, timeout=10.0) as resp:
+        # Create an opener that handles redirects properly for POST requests
+        class HTTPRedirectHandler(urllib.request.HTTPRedirectHandler):
+            def redirect_request(self, req, fp, code, msg, headers, newurl):
+                """Handle redirect while preserving POST method and data for 307/308."""
+                if code in (307, 308):
+                    # Preserve method and data for 307 and 308 redirects
+                    return urllib.request.Request(
+                        newurl,
+                        data=req.data,
+                        headers=req.headers,
+                        origin_req_host=req.origin_req_host,
+                        unverifiable=req.unverifiable,
+                    )
+                # For other redirect codes, use default behavior
+                return super().redirect_request(req, fp, code, msg, headers, newurl)
+
+        opener = urllib.request.build_opener(HTTPRedirectHandler)
+        with opener.open(request, timeout=10.0) as resp:
             if resp.status >= 400:
                 print(f"[Paylink Tracer] Failed to send trace: HTTP {resp.status}")
     except Exception as e:
@@ -221,7 +238,7 @@ def paylink_tracer(func):
     Usage:
         # Configure once at startup
         configure(
-            base_url="https://api.paylink.com",
+            api_key="plk_live_abc123...",
             project_name="My Project",
             payment_provider="mpesa",
         )
